@@ -15,18 +15,18 @@ from selenium.webdriver.support.wait import WebDriverWait
 
 from je_web_runner.je_web_runner.web_element_wrapper import web_element_wrapper
 from je_web_runner.je_web_runner.webdriver_with_options import set_webdriver_options_capability_wrapper
-from je_web_runner.utils.assert_value.result_check import check_webdriver
+from je_web_runner.utils.assert_value.result_check import check_webdriver_details
 from je_web_runner.utils.exception.exception_tag import selenium_wrapper_web_driver_not_found_error
 from je_web_runner.utils.exception.exceptions import WebRunnerException, WebRunnerWebDriverIsNoneException
 from je_web_runner.utils.exception.exceptions import WebRunnerWebDriverNotFoundException
 from je_web_runner.utils.test_object.test_object_class import TestObject
 from je_web_runner.utils.test_object.test_object_record.test_object_record_class import test_object_record
+from je_web_runner.utils.test_record.test_record_class import record_action_to_list
 from je_web_runner.webdriver_download_manager.chrome import ChromeDriverManager
 from je_web_runner.webdriver_download_manager.firefox import GeckoDriverManager
 from je_web_runner.webdriver_download_manager.microsoft import EdgeChromiumDriverManager
 from je_web_runner.webdriver_download_manager.microsoft import IEDriverManager
 from je_web_runner.webdriver_download_manager.utils import ChromeType
-from je_web_runner.utils.test_record.test_record_class import record_action_to_list
 
 _webdriver_dict = {
     "chrome": webdriver.Chrome,
@@ -317,6 +317,7 @@ class WebDriverWrapper(object):
                 switch_type_dict.update(
                     {"alert": None}
                 )
+                print(repr(error), file=stderr)
             if switch_type in ["active_element", "alert"]:
                 record_action_to_list("webdriver wrapper switch", param, None)
                 return switch_type_dict.get(switch_type)
@@ -1142,7 +1143,7 @@ class WebDriverWrapper(object):
         """
         param = locals()
         try:
-            check_webdriver(self.current_webdriver, check_dict)
+            check_webdriver_details(self.current_webdriver, check_dict)
             record_action_to_list("webdriver wrapper check_current_webdriver", param, None)
         except Exception as error:
             print(repr(error), file=stderr)
