@@ -1,4 +1,3 @@
-import sys
 from sys import stderr
 
 from selenium.common.exceptions import WebDriverException
@@ -7,7 +6,7 @@ from selenium.webdriver.remote.webdriver import WebDriver
 from je_web_runner.je_web_runner.web_element_wrapper import web_element_wrapper
 from je_web_runner.je_web_runner.webdriver_wrapper import webdriver_wrapper
 from je_web_runner.utils.exception.exception_tag import selenium_wrapper_web_driver_not_found_error
-from je_web_runner.utils.exception.exceptions import WebDriverIsNoneException
+from je_web_runner.utils.exception.exceptions import WebRunnerWebDriverIsNoneException
 from je_web_runner.utils.test_object.test_object_record.test_object_record_class import test_object_record
 from je_web_runner.utils.test_record.test_record_class import record_action_to_list
 
@@ -39,6 +38,7 @@ class WebdriverManager(object):
 
     def change_webdriver(self, index_of_webdriver: int) -> None:
         """
+        change to target webdriver
         :param index_of_webdriver: change current webdriver to choose index webdriver
         :return: None
         """
@@ -66,6 +66,7 @@ class WebdriverManager(object):
 
     def close_choose_webdriver(self, webdriver_index: int) -> None:
         """
+        close choose webdriver
         :param webdriver_index: close choose webdriver on current webdriver list
         :return: None
         """
@@ -86,11 +87,11 @@ class WebdriverManager(object):
         """
         try:
             if self._current_webdriver_list is None:
-                raise WebDriverIsNoneException(selenium_wrapper_web_driver_not_found_error)
+                raise WebRunnerWebDriverIsNoneException(selenium_wrapper_web_driver_not_found_error)
             test_object_record.clean_record()
-            for not_closed_webdriver in self._current_webdriver_list:
-                not_closed_webdriver.close()
-            self.current_webdriver.quit()
+            for webdriver in self._current_webdriver_list:
+                webdriver.quit()
+            self._current_webdriver_list = list()
             record_action_to_list("web runner manager quit", None, None)
         except Exception as error:
             print(repr(error), file=stderr)
