@@ -1,6 +1,5 @@
 import sys
 import types
-from typing import Tuple
 
 from je_web_runner.je_web_runner.webrunner_manager import web_runner
 from je_web_runner.utils.exception.exception_tag import add_command_exception_tag
@@ -143,6 +142,8 @@ class Executor(object):
             except Exception as error:
                 print(repr(error), file=sys.stderr)
                 print(action, file=sys.stderr)
+                execute_record = "execute: " + str(action)
+                execute_record_dict.update({execute_record: repr(error)})
         for key, value in execute_record_dict.items():
             print(key)
             print(value)
